@@ -53,8 +53,8 @@ import (
 	healthpb "google.golang.org/grpc/health/grpc_health_v1"
 	"google.golang.org/grpc/metadata"
 
-	"github.com/temporalio/tctl/v2/cli/headersprovider"
-	"github.com/temporalio/tctl/v2/cli/plugin"
+	"github.com/temporalio/tctl/cli/headersprovider"
+	"github.com/temporalio/tctl/cli/plugin"
 )
 
 var netClient HttpGetter = &http.Client{
